#
# spec file for package libofx
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libofx
Version:        0.10.9
Release:        1.0.2.1.sr20250601
Summary:        OFX Command Parser and API
License:        GPL-2.0-or-later
Group:          Development/Libraries/Other
URL:            https://github.com/libofx/libofx
Source:         https://github.com/libofx/libofx/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         0001-Remove-handling-for-obsolete-partner-server.patch
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  help2man
BuildRequires:  opensp-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libxml++-2.6) >= 2.6

%description
LibOFX is a parser and API for applications to support
OFX command responses, usually provided by financial institutions for
statement downloads.

%package -n libofx7
Summary:        OFX Command Parser and API
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n libofx7
LibOFX is a parser and API for applications to support
OFX command responses, usually provided by financial institutions for
statement downloads.

%package devel
Summary:        Development files for libofx, an OFX Command Parser and API
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       glibc-devel
Requires:       libofx7 = %{version}
Requires:       opensp-devel

%description devel
LibOFX is a parser and API for applications to support
OFX command responses, usually provided by financial institutions for
statement downloads.

This subpackage contains the header files for the C API.

%prep
%autosetup -p1

chmod -x doc/ofx_sample_files/ofx_spec160_stmtrs_example.sgml
dos2unix doc/ofx_sample_files/*.ofx

%build
# CMake build system doesn't currently handle docs, create them manually
cd doc
# E: file-contains-date-and-time /usr/share/doc/packages/libofx/html/doxygen.css
sed -i '/HTML_TIMESTAMP/d' doxygen.cfg

doxygen -u doxygen.cfg
doxygen doxygen.cfg
cd ..

# lto causes build issues on leap and armv7l
%define _lto_cflags %{nil}

%cmake

%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_defaultdocdir}/%{name}
cp -a doc/ofx_sample_files/*.* %{buildroot}%{_defaultdocdir}/%{name}/
cp -a doc/html %{buildroot}%{_defaultdocdir}/%{name}/

# man pages
mkdir -p %{buildroot}%{_mandir}/man1
for prog in ofxconnect ofxdump; do
help2man -N --output=${prog}.1 %__builddir/${prog}/${prog}
install -m 0644 ${prog}.1 %{buildroot}%{_mandir}/man1
done

%fdupes %{buildroot}

%ldconfig_scriptlets -n libofx7

%files
%doc AUTHORS ChangeLog NEWS README
%doc %dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/*.ofx
%{_bindir}/ofx2qif
%{_bindir}/ofxconnect
%{_bindir}/ofxdump
%{_datadir}/libofx/
%{_mandir}/man1/*.1%{?ext_man}

%files -n libofx7
%license COPYING
%{_libdir}/libofx.so.7*

%files devel
%doc %{_defaultdocdir}/%{name}/html/
%doc %{_defaultdocdir}/%{name}/*.sgml
%doc %{_defaultdocdir}/%{name}/*.xml
%{_libdir}/libofx.so
%{_includedir}/libofx/
%{_libdir}/cmake/libofx/
%{_libdir}/pkgconfig/libofx.pc

%changelog
* Sun Jun 22 2025 Christophe Marin <christophe@krop.fr>
- Update to 0.10.9. Changes since 0.10.8:
  * Fix null pointer dereference bugs
  * Initial support for exporting Config.cmake with targets
  * Fix version and tools description in vcpkg.json
  * Add cpack rules for "make source_package"
  * Fix installation path of libofx.h
  * Rename some variables that shadowed others to clarify different meanings #75
  Changes in 0.10.7:
  * autotools: fix LIBOFX_MAJOR_VERSION and friends in libofx.h
  * CMake: miscellaneous fixes
  Changes in 0.10.6:
  * Update FindOpenSP; also allow to forcefully ENABLE SP_MULTI_BYTE
  * Add support for CMake build system
  * Minor code cleanup in CharStringtostring function and its header
  * Ignore SGML parser character error because the char is accepted fine
  * Fix find_dtd() when OFX_DTD_PATH env var is used
  * Add ./configure option to disable CLI tools
  * Only link ofx2qif against C++ STD lib
  * Win32 code fixes for MSVC compilation
  * Don't deconst iconv input buffer under Windows
- Use CMake for building libofx
- Add upstream change:
  * 0001-Remove-handling-for-obsolete-partner-server.patch
* Thu May  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.10.5
  * Fix missing include for ptrdiff_t on Homebrew
  * Fix parallel builds by fixing the man-page build
  * Remove all "using namespace std" directives
  * Fix some minor memory leaks
  * Revert typos fixes
* Tue Nov  9 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Require libofx7 from the devel package: requiring the library as
  the target to the .so symlink is mandatory.
* Thu Oct 14 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.10.3:
  * Fix gmt offset seconds
  * Fix various typos in source code
* Sun Sep 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.10.2
  * Improved imported date stability
  * Respect --libdir for opensp. Don't override docdir.
* Mon Mar  8 2021 Dirk Müller <dmueller@suse.com>
- update to 0.10.1:
  * Correct casting of iconv input argument
  * Let ofxdump also return an error value on error
  * Code cleanup towards normal C++
* Sun Jan 24 2021 Dirk Müller <dmueller@suse.com>
- update to 0.10.0:
  * fixed: Remove unimplemented function from libofx.h header
  * fixed: Return error value if file parsing is unsuccessful in libofx_proc_file
  * fixed: Use given parameter for actual file type in libofx_proc_file
  * Large contribution adding investment / security handling in OFX files, by jeffjl74.
    ABI-breaking change, hence MINOR version incremented (due to MAJOR still at zero),
  but libofx.h API should only have additions
  * jeffjl74 Enhanced handling of investments in OFX files (support not added to OFC)
  * increased OFX_SECNAME_LENGTH to match the OFX spec (ABI-breaking change,
  hence MINOR version incremented) OfxSecurityData now includes:
  - an enum for the type of the security (stock, bond, fund, option)
  - the optional <SECINFO> fields
  - the mandatory <DEBTINFO> and <OPTINFO> fields
  - the optional <DEBTINFO> and <OPTINFO> fields
  * added <INVBAL> parsing for cash balances in investment accounts
  - usefulness depends upon how the broker uses these fields
  - Vanguard fund account puts the market value in there instead of the cash balance
  - other tested brokers use it appropriately, though the date of the
  balance is sometimes inconsistent usually due to unsettled trades,
    i.e. the "as of" date will say "today" but the cash
  balance will actually be from a couple of days ago with the
    difference being unsettled trades.
  * <STMTTRN> fields under an <INVBANKTRAN> are now parsed into an
  OfxInvestmentTransactionContainer
  * added the fields from section 13.9.2.4.2 of OFX spec 2.1.1 to OfxTransactionData
  * added <INVPOS> support to provide balances for securities
  * added <CURRENCY>, <ORIGCURRENCY>, <CURRATE> and <CURSYM> parsing and fields to
    transactions, securities, and positions
  * added a new account type OfxAccountData::OFX_401K
  * added a fix for sourceforge bug #46 account callback on <TRANSFER>
  * modified ofxdump to support the above changes
  * added investment account examples from OFX 2.1.1 spec to "ofx_sample_files"
  * could not get openSP to parse ofx201.dtd
* Thu Aug 20 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.9.15:
- Fix segfault on uninitialized iconv
- Make file format less stringent
- Minor fixes in the build system
- Fix proprietary tags striping eating the content of the previous tag if
  proprietary tag is in the middle of the line
- Don't output invalid line numbers on the console before SGML processing starts
- Fix potential heap overflow
  - Fix crash on some malformed ofx files
  - Fix crash in ofxconnect on missing command line arguments
  - Fix for daylight savings time handling
  - Easier compile on macos:  obey LIBTOOLIZE env variable, and fallback to glibtoolize
  - Fix compile on win32 (mingw-w64)
  - Performance an reliability fixes in header parsing
  - Strip CATEGORY tag added by Chase bank
- remove libofx-CVE-2017-14731.patch (upstream)
* Thu Apr 19 2018 jengelh@inai.de
- Trim history from description. Remove ineffective --with-pic
  (applies to static libs only). Rectify RPM groups.
* Thu Mar 22 2018 dimstar@opensuse.org
- Update to version 0.9.12:
  + Fixing a buffer overflow (CVE-2017-2816).
- Add libofx-CVE-2017-14731.patch: Fix a buffer overflow on
  unexpected tag names (CVE-2017-14731, boo#1060437).
* Wed Sep 14 2016 fcrozat@suse.com
- Update to version 0.9.11:
  + Add support for client uid, from kde#366326 bug.
- Rename libofx6 subpackage to libofx7, following the soname bump.
- Delete backup files that should not be in the tarball.
* Wed Mar  2 2016 dimstar@opensuse.org
- Replace libxmll++-devel BuildRequires with
  pkgconfig(libxml++-2.6) in order to be ready for the
  compatibility package introduction (libxml++ goes 3.0).
* Fri Jan 30 2015 zaitor@opensuse.org
- Update to version 0.9.10:
  + Fix missing balance dates (ledger_balance_date,
    available_balance_date).
* Sun Dec 22 2013 zaitor@opensuse.org
- Update to version 0.9.9:
  + Fix missing increment of SO_CURRENT number in libofx-0.9.6 to
    avoid crashes when mixing this with older applications.
  + bug#41: Fix a crash that occurs while importing a possibly
    invalid OFX file.
- Rename libofx5 subpackage to libofx6, following the soname bump.
- Delete backup files that should not be in the tarball.
* Wed May 15 2013 dimstar@opensuse.org
- Update to version 0.9.8:
  + Fix errorneous reading of files with empty lines.
  + bug#24: Fix build error on solaris.
  + bug#40: Fix compiler warnings of OFX clang
- Changes from versiom 0.9.7:
  + Fix errorneous reading of files with long lines.
* Mon Apr  1 2013 zaitor@opensuse.org
- Update to version 0.9.6:
  + Extend buffer for TRANSACTION_NAME to 96 bytes due to UTF-8
    multibyte characters.
  + Fix typo in info message.
  + Allow lines longer than 1024 caracters.
  + Fix treatment of empty date strings: Must return a zero date
    instead of a bogus one.
  + Replace unlink() with remove() to fix compile problems with
    gcc 4.7
  + Make configure fail if gengetopt is missing and generated files
    are not present.
  + Fix garbled character encoding for UTF-8 encoded OFX 2.0 (XML)
    files. Sadly, because of a bug in OpenSP with xml decoding this
    currently means that iso-8859-1 OFX-2.0 files will still not be
    properly decoded.
- Drop libofx-gcc47.patch, fixed upstream.
* Wed Mar 14 2012 dimstar@opensuse.org
- Add libofx-gcc47.patch: Fix build with gcc 4.7.
* Wed Jan 11 2012 dimstar@opensuse.org
- Update to version 0.9.5:
  + Workaround OFX files specifying invalid encoding values
    (specifically:  UNICODE and CP1252). This should fix most
    encoding problems reported.
  + Look for DTD in source directory (simplifies developpement)
  + Add minor argument checking
  + Expose field: OfxSecurityData::fiid in API
  + Make string arguments a const reference where appropriate
  + Add configure check for help2man tool
  + Improve build system and autoconf 2.68 compatibility
  + Improve generated man pages
  + Use GCC's -fvisibility=hidden to hide internal symbols from
    external users.
- Rename libofx4 subpackage to libofx5, following the soname bump.
- Clean spec-file using spec-cleaner.
* Thu Jul 28 2011 vuntz@opensuse.org
- Fix build by not marking some non-directory files as %%dir in file
  list. This was wrong but only breaks now with newer rpm.
* Fri Jun 17 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to version 0.9.4:
  + Fix segfault on some malformed date formats.
  + LibOFX will now look for DTDs in env variable OFX_DTD_PATH.
  + Better handling of paths (tolerates trailing path separator,
    or lack thereof)
  + No longer ignore return value of mkstemp()
  + Move to LibXML++ 2.6, as 1.0 is deprecated
  + Add generated man pages with html2man
- Changes from version 0.9.3:
  + sf#2969817: Fix segfault on some files containing missing
    closing tags.
- Changes from version 0.9.2:
  + Win32: Look up the dtd installation directory from the current
    executable's location.
  + Fix a crash on invalid date format
  + Allow wrapping the library in python.
  + Fix "Transaction posting date off by one"
  + Various C++ include fixes for building with recent compilers.
- Drop libofx-0.8.2-gcc43.patch: fixed upstream.
- Use source services: download_url, recompress, set_version.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Feb 10 2009 vuntz@novell.com
- Update to version 0.9.1:
  + Add more sanity checks on string length
  + Fix gnucash crash on OFX files with non-ascii characters and
    very long lines (bgo#528306)
* Tue Jan 13 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Fri Feb  1 2008 rodrigo@suse.de
- Update to version 0.9.0:
  * Export version information thus allowing depending apps to
    determine the version of libOFX it is compiled against
  * Some fields have been added to OfxFiLogin to allow for
    modification of some OFX header fields in outgoing requests
  * Calling apps can now tell libofx where the data field resides
  * Some warnings for recent versions of GCC have been fixed
  * LibOFX can now easily be cross-compiled for Windows on Linux
  * The OFX header is now scanned for a hint regarding the encoding
    of the document and convert the data to UTF8 if iconv is
    available at compile time
  * The API for online requests has been cleaned up
- Rename libofx3 to libofx4
* Tue Nov 13 2007 mauro@suse.de
- bug fixes for the gcc 4.3 issue.
* Thu Oct  4 2007 maw@suse.de
- Split out a libofx3 subpackage
- Add %%post and %%postun sections
- Minor specfile cleanups.
* Tue Oct  3 2006 sbrabec@suse.cz
- Updated to version 0.8.2:
  * bug fixes for GCC4.x and 64-bit compatibility
  * fix to enable OFXDirectConnect in Aqbanking
  * improvements to ofxpartner functionality
  * minor build system modifications
  * new fields for fees, commissions and stock split data
  * fix a memory leak and a potential crashing bug
- Developer documentation moved to devel subpackage.
* Wed May 10 2006 sbrabec@suse.cz
- Split devel subpackage.
- Fixed dependencies.
- Enabled parallel build.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 ro@suse.de
- fix typo in makefile (LIBOBJ -> LIBOBJS)
* Wed Oct 19 2005 sbrabec@suse.cz
- Updated to version 0.8.0.
* Mon Apr 25 2005 gekker@suse.de
- Add libofx-gcc4.patch to fix GCC4 complilation.
* Mon Feb 21 2005 sbrabec@suse.cz
- Updated to version 0.7.0.
* Thu Feb 19 2004 sbrabec@suse.cz
- Updated to version 0.6.6.
* Thu Jun 12 2003 kukuk@suse.de
- Add missing directories to filelist
* Sun Jun  1 2003 ro@suse.de
- remove unpackaged files from buildroot
* Mon Feb 17 2003 sf@suse.de
- added path to libopensp
* Fri Feb  7 2003 hhetter@suse.de
- initial package
